@@ -1,12 +1,12 @@
 #' @title A parametrized log Normal probability distribution
 #' @description An R6 class representing a log Normal distribution.
 #' @details A parametrized Log Normal distribution inheriting from class
-#' \code{Distribution}. Swat (2017) defined seven parametrizations of the log 
-#' normal distribution. 
-#' These are linked, allowing the parameters of any one to be derived from any 
+#' \code{Distribution}. Swat (2017) defined seven parametrizations of the log
+#' normal distribution.
+#' These are linked, allowing the parameters of any one to be derived from any
 #' other. All 7 parametrizations require two parameters as follows:
 #' \describe{
-#' \item{LN1}{\eqn{p_1=\mu}, \eqn{p_2=\sigma}, where \eqn{\mu} and \eqn{\sigma} 
+#' \item{LN1}{\eqn{p_1=\mu}, \eqn{p_2=\sigma}, where \eqn{\mu} and \eqn{\sigma}
 #' are the mean and standard deviation, both on the log scale.}
 #' \item{LN2}{\eqn{p_1=\mu}, \eqn{p_2=v}, where \eqn{\mu} and \eqn{v} are the
 #' mean and variance, both on the log scale.}
@@ -18,33 +18,32 @@
 #' \item{LN5}{\eqn{p_1=\mu}, \eqn{p_2=\tau}, where \eqn{\mu} is the mean on the
 #' log scale and \eqn{\tau} is the precision on the log scale.}
 #' \item{LN6}{\eqn{p_1=m}, \eqn{p_2=\sigma_g}, where \eqn{m} is the median on
-#' the natural scale and \eqn{\sigma_g} is the geometric standard deviation on 
+#' the natural scale and \eqn{\sigma_g} is the geometric standard deviation on
 #' the natural scale.}
 #' \item{LN7}{\eqn{p_1=\mu_N}, \eqn{p_2=\sigma_N}, where \eqn{\mu_N} is the mean
 #' on the natural scale and \eqn{\sigma_N} is the standard deviation on the
 #' natural scale.}
 #' }
-#' @references{ 
+#' @references{
 #'  Briggs A, Claxton K and Sculpher M. Decision Modelling for Health
 #'  Economic Evaluation. Oxford 2006, ISBN 978-0-19-852662-9.
 #'
 #'  Leaper DJ, Edmiston CE and Holy CE. Meta-analysis of the potential
-#'  economic impact following introduction of absorbable antimicrobial 
+#'  economic impact following introduction of absorbable antimicrobial
 #'  sutures. \emph{British Journal of Surgery} 2017;\bold{104}:e134-e144.
 #'
 #'  Swat MJ, Grenon P and Wimalaratne S. Ontology and Knowledge Base of
-#'  Probability Distributions. \acronym{EMBL-EBI} Technical Report
-#'  (ProbOnto 2.5), 13 January 2017, 
-#'  \url{https://sites.google.com/site/probonto/download}.
+#'  Probability Distributions. \emph{Bioinformatics} 2016;\bold{32}:2719-2721,
+#'  \doi{10.1093/bioinformatics/btw170}.
 #' }
-#' @note The log normal distribution may be used to model the uncertainty in 
-#' an estimate of relative risk (Briggs 2006, p90). If a relative risk 
-#' estimate is available with a 95\% confidence interval, the \verb{"LN7"} 
+#' @note The log normal distribution may be used to model the uncertainty in
+#' an estimate of relative risk (Briggs 2006, p90). If a relative risk
+#' estimate is available with a 95\% confidence interval, the \verb{"LN7"}
 #' parametrization
-#' allows the uncertainty distribution to be specified directly. For example, 
-#' if RR = 0.67 with 95\% confidence interval 0.53 to 0.84 (Leaper, 2016), it 
+#' allows the uncertainty distribution to be specified directly. For example,
+#' if RR = 0.67 with 95\% confidence interval 0.53 to 0.84 (Leaper, 2016), it
 #' can be modelled with
-#' \code{LogNormModVar$new("rr", "RR", p1=0.67, 
+#' \code{LogNormModVar$new("rr", "RR", p1=0.67,
 #' p2=(0.84-0.53)/(2*1.96)), "LN7")}.
 #' @docType class
 #' @author Andrew J. Sims \email{andrew.sims@@newcastle.ac.uk}
@@ -59,9 +58,9 @@ LogNormDistribution <- R6::R6Class(
     parametrization = NULL
   ),
   public = list(
-    
-    #' @description Create a log normal distribution. 
-    #' @param p1 First hyperparameter, a measure of location. See 
+
+    #' @description Create a log normal distribution.
+    #' @param p1 First hyperparameter, a measure of location. See
     #' \emph{Details}.
     #' @param p2 Second hyperparameter, a measure of spread. See \emph{Details}.
     #' @param parametrization A character string taking one of the values
@@ -72,11 +71,11 @@ LogNormDistribution <- R6::R6Class(
       super$initialize("LogNorm", K = 1L)
       # check that p1 and p2 are numeric
       abortifnot(is.numeric(p1),
-        message = "Argument 'p1' must be numeric", 
+        message = "Argument 'p1' must be numeric",
         class = "p1_not_numeric"
       )
       abortifnot(is.numeric(p2),
-        message = "Argument 'p2' must be numeric", 
+        message = "Argument 'p2' must be numeric",
         class = "p2_not_numeric"
       )
       # transform parameters according to parametrization
@@ -95,16 +94,16 @@ LogNormDistribution <- R6::R6Class(
         private$sdlog <- sqrt(log(p2 ^ 2L + 1L))
       } else if (parametrization == "LN5") {
         private$meanlog <- p1
-        private$sdlog <- 1L/sqrt(p2)
+        private$sdlog <- 1L / sqrt(p2)
       } else if (parametrization == "LN6") {
-        private$meanlog <- log(p1) 
+        private$meanlog <- log(p1)
         private$sdlog <- log(p2)
       } else if (parametrization == "LN7") {
-        private$meanlog <- log(p1 / sqrt(1L + (p2 ^ 2L) / (p1 ^ 2L))) 
+        private$meanlog <- log(p1 / sqrt(1L + (p2 ^ 2L) / (p1 ^ 2L)))
         private$sdlog <- sqrt(log(1L + (p2 ^ 2L) / (p1 ^ 2L)))
       } else {
         abortif(TRUE,
-          message = "'parametrize' must be one of 'LN1' through 'LN7'",
+          message = "'parametrization' must be one of 'LN1' through 'LN7'",
           class = "parametrization_not_supported"
         )
       }
@@ -123,12 +122,12 @@ LogNormDistribution <- R6::R6Class(
       )
       return(rv)
     },
-    
-    #' @description Draw a random sample from the model variable. 
+
+    #' @description Draw a random sample from the model variable.
     #' @param expected If TRUE, sets the next value retrieved by a call to
     #' \code{r()} to be the mean of the distribution.
     #' @return Updated \code{LogNormDistribution} object.
-    sample = function(expected=FALSE) {
+    sample = function(expected = FALSE) {
       if (!expected) {
         private$.r[[1L]] <- rlnorm(
           n = 1L, mean = private$meanlog, sd = private$sdlog
@@ -138,37 +137,37 @@ LogNormDistribution <- R6::R6Class(
       }
       return(invisible(self))
     },
-    
-    #' @description Return the expected value of the distribution. 
+
+    #' @description Return the expected value of the distribution.
     #' @return Expected value as a numeric value.
     mean = function() {
       E <- exp(private$meanlog + 0.5 * private$sdlog ^ 2L)
       return(E)
     },
-    
-    #' @description Return the point estimate of the variable. 
+
+    #' @description Return the point estimate of the variable.
     #' @return Point estimate (mode) of the log normal distribution.
     mode = function() {
       return(exp(private$meanlog - private$sdlog ^ 2L))
     },
-    
-    #' @description Return the standard deviation of the distribution. 
+
+    #' @description Return the standard deviation of the distribution.
     #' @return Standard deviation as a numeric value
     SD = function() {
       S <- exp(private$meanlog + 0.5 * private$sdlog ^ 2L) *
-           sqrt(exp(private$sdlog ^ 2L) - 1L)
+        sqrt(exp(private$sdlog ^ 2L) - 1L)
       return(S)
     },
-    
+
     #' @description Return the quantiles of the log normal distribution.
-    #' @param probs Vector of probabilities, in range [0,1].    
+    #' @param probs Vector of probabilities, in range [0,1].
     #' @return Vector of quantiles.
     quantile = function(probs) {
       # test argument
-      vapply(probs, FUN.VALUE = TRUE, FUN=function(x) {
+      vapply(probs, FUN.VALUE = TRUE, FUN = function(x) {
         abortif(is.na(x),
           message = "All elements of 'probs' must be defined",
-          class="probs_not_defined"
+          class = "probs_not_defined"
         )
         abortifnot(is.numeric(x),
           message = "Argument 'probs' must be a numeric vector",
@@ -180,7 +179,7 @@ LogNormDistribution <- R6::R6Class(
         )
         return(TRUE)
       })
-      q <- qlnorm(probs, mean=private$meanlog, sd=private$sdlog)
+      q <- qlnorm(probs, mean = private$meanlog, sd = private$sdlog)
       return(q)
     }
   )
