@@ -21,7 +21,7 @@ test_that("properties are set correctly", {
   expect_true(z$is_probabilistic())
 })
 
-test_that("ExprModVar obeys scoping rules" , {
+test_that("ExprModVar obeys scoping rules", {
   # operands in a function environment (test_that)
   x <- 2L
   y <- 3L
@@ -76,7 +76,7 @@ test_that("operands are identified correctly", {
   })
   expect_setequal(d, c("y", "z"))
   # nested case, with repeats
-  e1 <- ExprModVar$new("e1", "GBP", quo = rlang::quo(x*y + z))
+  e1 <- ExprModVar$new("e1", "GBP", quo = rlang::quo(x * y + z))
   e2 <- ExprModVar$new("e2", "GBP", quo = rlang::quo(z + 3.0))
   e3 <- ExprModVar$new("e3", "GBP", quo = rlang::quo(e1 + e2))
   mv <- e3$operands()
@@ -94,7 +94,7 @@ test_that("operands are identified correctly", {
   expect_setequal(d, c("e1", "e2", "e3", "y", "z"))
   # nesting without recursion
   mv <- e3$operands(recursive = FALSE)
-  d <- vapply(mv, FUN.VALUE = "x", FUN= function(v) {
+  d <- vapply(mv, FUN.VALUE = "x", FUN = function(v) {
     return(v$description())
   })
   expect_setequal(d, c("e1", "e2"))
@@ -104,7 +104,7 @@ test_that("set and get function as expected", {
   # check initialization
   x <- 2L
   y <- NormModVar$new("y", "GBP", mu = 0.0, sigma = 1.0)
-  z <- ExprModVar$new("z", "GBP", quo=rlang::quo(x * y))
+  z <- ExprModVar$new("z", "GBP", quo = rlang::quo(x * y))
   expect_false(is.na(z$get()))
   # check illegal input
   expect_error(z$set(TRUE), class = "what_not_character")
@@ -122,7 +122,7 @@ test_that("set and get function as expected", {
   expect_gt(v, 3.5)
   # check mean is within 3.29 std errors (roughly 0.1%)
   z$set("expected")
-  tol <- 3.29 * 2.0/sqrt(1000.0)
+  tol <- 3.29 * 2.0 / sqrt(1000.0)
   expect_intol(z$get(), 0.0, tol)
   # check that set() for operands affects get() for the expression
   y$set("q97.5")
@@ -130,14 +130,14 @@ test_that("set and get function as expected", {
   expect_gt(z$get(), 3.5)
   y$set("expected")
   expect_intol(z$get(), 0.0, tol)
-  # check that a random sample from z is from a SN*2, despite setting y 
+  # check that a random sample from z is from a SN*2, despite setting y
   n <- 1000L
   S <- vector(mode = "numeric", length = n)
   for (i in seq_len(n)) {
     y$set("q97.5")
     z$set("random")
-    S[[i]] <- z$get() 
-  } 
+    S[[i]] <- z$get()
+  }
   # 99.9% confidence limits; expected 0.1% test failure rate; skip for CRAN
   ht <- ks.test(S, rnorm(n, mean = 0.0, sd = 2.0))
   expect_gt(ht$p.value, 0.001)
@@ -165,7 +165,7 @@ test_that("modified expressions are created correctly", {
   # check internally added methods; 99.9% confidence limits assuming CLT; expect
   # 0.1% test failure rate; skip for CRAN
   n <- 1000L
-  samp <- vapply(seq_len(n), FUN.VALUE = 1.0, FUN=function(i) {
+  samp <- vapply(seq_len(n), FUN.VALUE = 1.0, FUN = function(i) {
     q$set("random")
     rv <- q$get()
     return(rv)
@@ -181,15 +181,15 @@ test_that("illegal sample sizes for estimating parameters are rejected", {
   y <- NormModVar$new("y", "GBP", mu = 0.0, sigma = 1.0)
   z <- ExprModVar$new("z", "GBP", quo = rlang::quo(x * y))
   expect_error(
-    ExprModVar$new("z", "GBP", quo = rlang::quo(x * y), "100"), 
-    class="nemp_not_integer"
+    ExprModVar$new("z", "GBP", quo = rlang::quo(x * y), "100"),
+    class = "nemp_not_integer"
   )
   expect_error(
     ExprModVar$new("z", "GBP", quo = rlang::quo(x * y), 100L),
-    class="nemp_too_small"
+    class = "nemp_too_small"
   )
   expect_error(
-    ExprModVar$new("z", "GBP", quo = rlang::quo(x*y), 999.5), 
+    ExprModVar$new("z", "GBP", quo = rlang::quo(x * y), 999.5),
     class = "nemp_not_integer"
   )
   expect_silent(
@@ -206,11 +206,11 @@ test_that("quantile estimation checks inputs and has correct output", {
   probs <- c(0.1, 0.2, 0.5)
   expect_silent(q$q_hat(probs))
   probs <- c(0.1, NA_real_, 0.5)
-  expect_error(q$q_hat(probs), class="probs_not_defined")
+  expect_error(q$q_hat(probs), class = "probs_not_defined")
   probs <- c(0.1, "boo", 0.5)
-  expect_error(q$q_hat(probs), class="probs_not_numeric")
+  expect_error(q$q_hat(probs), class = "probs_not_numeric")
   probs <- c(0.1, 0.4, 1.5)
-  expect_error(q$q_hat(probs), class="probs_out_of_range")
+  expect_error(q$q_hat(probs), class = "probs_out_of_range")
   probs <- c(0.1, 0.2, 0.5)
   expect_length(q$q_hat(probs), 3L)
 })
@@ -222,8 +222,8 @@ test_that("nested expressions are evaluated correctly", {
   sn1 <- NormModVar$new("sn1", "", mu = 0.0, sigma = 1.0)
   s1 <- ExprModVar$new("s1", "", rlang::quo(1.0 * sn1))
   # tolerance is 3.29 * standard error (roughly 0.1%)
-  tol <- 3.29*sqrt(2.0) / sqrt(1000L)
-  # check that all 3 products have a mean of 1 (chisq with 1 dof)   
+  tol <- 3.29 * sqrt(2.0) / sqrt(1000L)
+  # check that all 3 products have a mean of 1 (chisq with 1 dof)
   p1 <- ExprModVar$new("p1", "", rlang::quo(sn1 * sn1))
   expect_intol(p1$mu_hat(), 1.0, tol)
   p2 <- ExprModVar$new("p2", "", rlang::quo(s1 * s1))
@@ -246,23 +246,38 @@ test_that("autocorrelation in nested expressions is preserved", {
   zc <- ExprModVar$new("zc", "", rlang::quo(x * s1))
   zu <- ExprModVar$new("zu", "", rlang::quo(y * s1))
   # tolerance is 3.29 * standard error (roughly 0.1%)
-  tol <- 3.29*sqrt(2.0)/sqrt(1000L)
+  tol <- 3.29 * sqrt(2.0) / sqrt(1000L)
   # zc is a chi-squared with 1 dof
   expect_intol(zc$mu_hat(), 1.0, tol)
   # zu is a modified Bessel function with mean 0 and sd 1
   expect_intol(zu$mu_hat(), 0.0, tol)
 })
 
+test_that("scalar expression is evaluated correctly", {
+  x <- ExprModVar$new("x", "", rlang::quo(1.0))
+  expect_false(x$is_probabilistic())
+  expect_length(x$operands(), 0L)
+  expect_identical(x$distribution(), "1")
+  expect_intol(x$mean(), 1.0, 0.001)
+  expect_true(is.na(x$mode()))
+  expect_true(is.na(x$SD()))
+  expect_identical(x$quantile(probs = c(0.025, 0.975)), c(NA_real_, NA_real_))
+  expect_intol(x$mu_hat(), 1.0, 0.01)
+  expect_intol(x$sigma_hat(), 0.0, 0.01)
+  expect_intol(x$q_hat(probs = 0.025), 1.0, 0.01)
+  expect_intol(x$q_hat(probs = 0.975), 1.0, 0.01)
+})
+
 test_that("expression chi square from SN is correct", {
-  # skip on cran because tests involve sampling
-  skip_on_cran()
-  # x ~ N(0,1), y = x^2 ~ Chisq(k=1) 
+  # x ~ N(0,1), y = x^2 ~ Chisq(k=1)
   k <- 1L
   x <- NormModVar$new("x", "", mu = 0.0, sigma = 1.0)
-  y <- ExprModVar$new("y","",rlang::quo(x ^ 2L))
+  y <- ExprModVar$new("y", "", rlang::quo(x ^ 2L))
   # check that mode and SD are undefined
   expect_true(is.na(y$mode()))  # mode is undefined for ExprModVar
   expect_true(is.na(y$SD()))  # SD is undefined for ExprModVar
+  # skip sampling tests on cran
+  skip_on_cran()
   # tolerance is 3.29 * standard error (roughly 0.1%)
   tol <- 3.29 * sqrt(2L * k) / sqrt(1000L)
   expect_equal(y$mean(), 0.0)          # product of operand means is 0
@@ -271,7 +286,7 @@ test_that("expression chi square from SN is correct", {
   expect_intol(y$q_hat(p = 0.5), median, tol)
   # generate a distribution and check it
   n <- 1000L
-  samp <- vapply(seq_len(n), FUN.VALUE = 1.0, FUN=function(i) {
+  samp <- vapply(seq_len(n), FUN.VALUE = 1.0, FUN = function(i) {
     y$set("random")
     rv <- y$get()
     return(rv)
@@ -298,10 +313,10 @@ test_that("one Dirichlet matches a Beta and an expression", {
   # compare means
   expect_identical(p$mean(), p.d$mean())
   expect_intol(q$mean(), q.d$mean(), tol)
-  # compare quantiles for p 
-  probs<- c(0.025, 0.975)
+  # compare quantiles for p
+  probs <- c(0.025, 0.975)
   expect_setequal(unname(p$quantile(probs)), unname(p.d$quantile(probs)))
-  # quantiles defined for q.d but not q 
+  # quantiles defined for q.d but not q
   expect_true(all(is.na(q$quantile(probs))))
   expect_false(anyNA(q.d$quantile(probs)))
 })
