@@ -7,7 +7,9 @@ test_that("illegal initializations are rejected", {
   expect_error(
     NormModVar$new("norm", 42L, 0.0, 1.0), class = "units_not_string"
   )
-  expect_error(NormModVar$new("norm", "GBP","0", 1.0), class = "mu_not_numeric")
+  expect_error(
+    NormModVar$new("norm", "GBP", "0", 1.0), class = "mu_not_numeric"
+  )
   expect_error(
     NormModVar$new("norm", "GBP", 0.0, "1"), class = "sigma_not_numeric"
   )
@@ -21,9 +23,9 @@ test_that("properties are correct", {
 
 test_that("modvar has correct distribution name", {
   sn <- NormModVar$new("sn", "GBP", 0.0, 1.0)
-  expect_identical(sn$distribution(), "N(0,1)")  
+  expect_identical(sn$distribution(), "N(0,1)")
   n <- NormModVar$new("n", "GBP", 42.0, 1.0)
-  expect_identical(n$distribution(), "N(42,1)")  
+  expect_identical(n$distribution(), "N(42,1)")
 })
 
 test_that("quantile function checks inputs", {
@@ -31,11 +33,11 @@ test_that("quantile function checks inputs", {
   probs <- c(0.1, 0.2, 0.5)
   expect_silent(x$quantile(probs))
   probs <- c(0.1, NA, 0.5)
-  expect_error(x$quantile(probs), class="probs_not_defined")
+  expect_error(x$quantile(probs), class = "probs_not_defined")
   probs <- c(0.1, "boo", 0.5)
-  expect_error(x$quantile(probs), class="probs_not_numeric")
+  expect_error(x$quantile(probs), class = "probs_not_numeric")
   probs <- c(0.1, 0.4, 1.5)
-  expect_error(x$quantile(probs), class="probs_out_of_range")
+  expect_error(x$quantile(probs), class = "probs_out_of_range")
   probs <- c(0.1, 0.2, 0.5)
   expect_length(x$quantile(probs), 3L)
 })
@@ -55,7 +57,7 @@ test_that("random sampling is from a Normal disribution", {
   sigma <- 1.0
   sn <- NormModVar$new("sn", "GBP", mu, sigma)
   n <- 1000L
-  samp <- vapply(seq_len(n), FUN.VALUE = 1.0, FUN=function(i) {
+  samp <- vapply(seq_len(n), FUN.VALUE = 1.0, FUN = function(i) {
     sn$set("random")
     rv <- sn$get()
     return(rv)
@@ -64,13 +66,13 @@ test_that("random sampling is from a Normal disribution", {
   # check sample mean and sd are within 99.9% CI based on CLT; this is exact
   # for a normal, and is expected to fail for 0.1% of tests; skip for CRAN
   skip_on_cran()
-  ht <- ks.test(samp, rnorm(n,mean = mu, sd = sigma))
+  ht <- ks.test(samp, rnorm(n, mean = mu, sd = sigma))
   expect_gt(ht$p.value, 0.001)
 })
 
 test_that("First call to get() returns mean", {
   sn <- NormModVar$new("sn", "GBP", 0.0, 1.0)
-  expect_identical(sn$get(), 0.0)  
+  expect_identical(sn$get(), 0.0)
 })
 
 test_that("variable passing and persistency of get and set are correct", {
